function [ drawnReturns ] = calculateRandomReturnFromQuantiles( simulatedReturns, rowSize)
% Interpolates the quantiles and draws a random return from
% this distribution for each stock, returns a matrix on the form
% [date stockReturn1 ... stockReturnN]
%
% simulatedReturns: matrix with conditional returns for each stock
% [date return quantile index]
% rowSize: rowSize of data at one date

CORRECT_DATAPOINTS = true;

nrOfStocks = simulatedReturns(end,end);
nrOfQunatiles = rowSize / nrOfStocks;

% nr of rows in drawReturns matrix
nrOfRows = size(simulatedReturns,1) / rowSize;

drawnReturns = zeros(nrOfRows, nrOfStocks + 1);

bottomIndex = 0;

for i=1:nrOfRows
    for j=1:nrOfStocks

        topIndex = bottomIndex + 1;
        bottomIndex = topIndex + nrOfQunatiles - 1;
        
        % extract current data from simulated returns [ret percentile]
        dataPoints = simulatedReturns(topIndex:bottomIndex, 2:3);
        
        % begin interpolation procedure
        minRet = min(dataPoints(:,1));
        maxRet = max(dataPoints(:,1));
        xx = minRet:0.0001:maxRet;
        
        if CORRECT_DATAPOINTS
            xPoints = sort(dataPoints(:,1));
            yPoints = sort(dataPoints(:,2));
        else
            xPoints = dataPoints(:,1);
            yPoints = dataPoints(:,2);
        end
        
        % Alternative interpolation functions tested
        %interpolationFunc = spline(dataPoints(:,1), dataPoints(:,2), xx);
        %interpolationFunction = @(xx) pchip(dataPoints(:,1), dataPoints(:,2), xx);
        interpolationFunc = pchip(xPoints, yPoints, xx);
        
        % to get conditional distribution
        %{
        if j==4
            mekk = [transpose(xx) transpose(interpolationFunc)];
            csvwrite(strcat('condDist',num2str(ind),'.csv'),mekk);
        end
        %}

        % Polyfit function tested
        %p = polyfit(xPoints,yPoints,3);
        %interpolationFunc = polyval(p,xx);
        
        % uncomment to plot the interpolation, uncomment the figure you want
        %plot(xx,interpolationFunc,dataPoints(:,1),dataPoints(:,2),'o',xPoints, yPoints,'*');
        %disp(dataPoints(:,1));
        % draw random return
        drawnReturns(i,j+1) = calculateInverse(interpolationFunc, xx, rand);
    end
end

if nrOfRows > 1
    dates = removeDupSorted(simulatedReturns(:,1));
    drawnReturns(:,1) = dates;
else
    drawnReturns(1,1) = simulatedReturns(end,1);
end

end

