function [ simReturns ] = calculateSimulatedCondQuantiles(QregResults, simPCs)
% Returns new simulated conditional returns based on simulated explanatory
% variables (simulated principal components) [date return percentile index]
% Uses the PCA factor model from the simulation framework
%
% QregResults: result matrix of quantile regressions [alpha beta1 ... betaN
% percentile index]
% simPCs: matrix of simulated principal components [Date simPC1 ... simPCN]

simulationSteps = size(simPCs,1);

rowSize = size(QregResults,1);

simRet = zeros(rowSize * simulationSteps, 4);

bottomIndex = 0;

for i=1:simulationSteps
    % get date of simulation
    date = simPCs(i,1);
    
    % prepare simulated principal components for matrix multiplication
    tempsimPCs = [1 ; transpose(simPCs(i,2:end))];
    
    topIndex = bottomIndex + 1;
    bottomIndex = topIndex + rowSize - 1;

    simRet(topIndex:bottomIndex,1) = date;
    simRet(topIndex:bottomIndex,2) = QregResults(:,1:size(QregResults,2)-2) * tempsimPCs;
    simRet(topIndex:bottomIndex,3:4) = QregResults(:,size(QregResults,2)-1:end);
end


simReturns = simRet;

end

