function [ TRC ] = calculateTotalRiskContribution(assetReturns, assetWeights, percentile, assetIndex, risk )
% Returns total risk contribution used in RP optimization
%
% stockReturnDistributions: Txn matrix on the form [Date stock1 ... stockn]
% portfolioWeights: nx1 vector of the portfolio weights
% percentile: VaR/CVaR percentile used as risk measure
% currentRisk: current Risk value of the portfolio with the current
% portfolioweights
% risk: string of wich risk measure to use

% specify change in x value in the derivation
deltaX = 0.0000001;
global covarMat;
global noIterations;

newPortfolioWeights = assetWeights;
newPortfolioWeights(assetIndex,1) = assetWeights(assetIndex,1) + deltaX;

% portfolio distributions
portfolioDistribution = calculatePortfolioRandomReturnFromQuantiles(assetReturns,assetWeights);
newPortfolioDistribution = calculatePortfolioRandomReturnFromQuantiles(assetReturns,newPortfolioWeights);
    
if strcmp(risk, 'cvar')
    noIterations = noIterations + 1;
    currentRisk = calculatePortfolioCVar(portfolioDistribution, percentile);
    newRisk = calculatePortfolioCVar(newPortfolioDistribution,percentile);
    MRC = (newRisk - currentRisk) / deltaX;
    
elseif strcmp(risk, 'vol')
    noIterations = noIterations + 1;
    sumWeightStdI = 0;
    for j = 1:length(assetWeights)
        sumWeightStdI = sumWeightStdI + assetWeights(assetIndex) * covarMat(assetIndex,j);
    end
    MRC = sumWeightStdI / std(portfolioDistribution(:,2));
elseif strcmp(risk, 'downVol')
    noIterations = noIterations +1;
    currentRisk = calculatePortfolioDownsideDeviation(portfolioDistribution);
    newRisk = calculatePortfolioDownsideDeviation(newPortfolioDistribution);
    MRC = (newRisk - currentRisk) / deltaX;
end

TRC = assetWeights(assetIndex)*MRC;

end