function [ simulatedReturnDistributions ] = mainSimulationParallelComputingAsFunction(tenKPartIndex, sector)
% Main script for simulation run as function

% CONSTANTS
varExpMargin = 0.95; % requirement of variance explained
varExpMarginStr = num2str(varExpMargin * 100);
sector = num2str(sector);
fileNameRetMat = strcat('../data/ReturnMatrices/returnMatrixSP80Sector',sector,'.csv');
simulationSteps = 1; % nr of steps into the future
numberOfSimulations = 100000; % total simulation runs
dayInterval = 30;
tenKPartIndexStr = num2str(tenKPartIndex);
%stockInfo = tickerDataImporter('stockInfoDatasetSector.csv', true);
%stockIndices = getStockIndexToSectorCode(stockInfo);

% MAIN SIMULATION PREPROCESSING START
% ---------------------------------------------

% get return data from file
ReturnMatrix = csvImporter(fileNameRetMat, true);

% filter return matrix on stock sector
%[ReturnMatrix, currentStockIndices] = getSectorReturnMatrix(ReturnMatrix, stockIndices, sectorCode);

% perform PCA on the return matrix
PCs = principalComponentAnalysis(ReturnMatrix, varExpMargin);

% write PCs to file to be importet by qreg script
%csvwrite(strcat('PCAColumnsSP80Sector',sector,'VarExp',varExpMarginStr,'.csv'),PCs);

% RUN QUNATILE REGRESSION SCRIPT IN R HERE

% import qreg results from qreg script
QregResults = csvImporter(strcat('../data/QuantileRegression/quantRegSP80Sector',sector,'varExp',varExpMarginStr,'.csv'),true);

% MAIN SIMULATION PREPROCESSING STOP
% ---------------------------------------------



% MAIN SIMULATION START
% ---------------------------------------------

% start time counter
tic

% PCA calculations
% ---------------------------------------------
% get drift of stocks
mu = mean(ReturnMatrix);
% get covar of returns matrix NxN
covarMat = cov(ReturnMatrix(:,2:end));
% get vector of eigen values
[eigenMatrix, eigenVec] = eig(covarMat);
eigenMatrix = fliplr(eigenMatrix);
% how many dimensions do we need to cover the margin
nrColsNeeded = getNumberOfPCColumns(eigenVec, varExpMargin);
% reduce the eigenmatrix
eigenMatrixShort = eigenMatrix(:,1:nrColsNeeded);
% calculate new reduced covariance matrix
reducedCovarMat = transpose(eigenMatrixShort) * covarMat * eigenMatrixShort;
% Cholesky decompose the reduced covariance matrix
redCovarMatCholesky = chol(reducedCovarMat);
% get last date of data
lastDate = ReturnMatrix(end,1);
% ---------------------------------------------

% First simulation start
% ---------------------------------------------
% simulate principal components into the future
simulatedPCs = principalComponentSimulationMinor(eigenMatrixShort, redCovarMatCholesky, mu, nrColsNeeded, lastDate, dayInterval,simulationSteps);

% calculate the conditional quantile returns based on estimated parameters
simulatedReturns = calculateSimulatedCondQuantiles(QregResults, simulatedPCs);

drawnRets = calculateRandomReturnFromQuantiles(simulatedReturns, size(simulatedReturns,1) / simulationSteps);

% allocate space to store return distribtutions
drawnReturns = zeros(numberOfSimulations, size(drawnRets,2));
% insert first row of drawn returns
drawnReturns(1,:) = drawnRets;
% First simulation stop
% ---------------------------------------------

% prepare input matrix for parallel processing
% number of input variables in parallel for-loop = 8
inputCell = cell(numberOfSimulations, 8);
inputCell = fillCellArray(inputCell, 1, QregResults);
inputCell = fillCellArray(inputCell, 2, eigenMatrixShort);
inputCell = fillCellArray(inputCell, 3, redCovarMatCholesky);
inputCell = fillCellArray(inputCell, 4, mu);
inputCell = fillCellArray(inputCell, 5, nrColsNeeded);
inputCell = fillCellArray(inputCell, 6, lastDate);
inputCell = fillCellArray(inputCell, 7, dayInterval);
inputCell = fillCellArray(inputCell, 8, simulationSteps);

% start parallel simulation loop
parfor i=2:numberOfSimulations
    tempSimPCs = principalComponentSimulationMinor(inputCell{i}{2}, inputCell{i}{3}, inputCell{i}{4}, inputCell{i}{5}, inputCell{i}{6}, inputCell{i}{7}, inputCell{i}{8});
    tempSimReturns = calculateSimulatedCondQuantiles(inputCell{i}{1}, tempSimPCs);
    
    tempDrawnRets = calculateRandomReturnFromQuantiles(tempSimReturns, size(tempSimReturns,1) / inputCell{i}{8});
    drawnReturns(i,:) = tempDrawnRets;
end

% finish time counter
toc

% MAIN SIMULATION STOP
% ---------------------------------------------

% write D (drawnReturns) to file
csvwrite(strcat('drawnReturnsSP80Sector',sector,'varExp',varExpMarginStr,'RunNr',tenKPartIndexStr,'.csv'),drawnReturns);

disp(strcat('Simulation step', tenKPartIndexStr,' complete'));