function optimizationFunction(noAssetsIn, percentileIn, riskIn, startSector, endSector)
% Main script for simulation run

%% Constants
global noAssets;
global percentile;
global risk;
global assetReturns;
global covarMat;
global elapsedTime;
global noIterations;
noIterations = 0;
%% Initializations
noAssets = noAssetsIn;
percentile = percentileIn;
risk = riskIn;

% Concatenate the matrix of all asset sectors
assetReturns = supportConcatenateSectors80(startSector,endSector,true);

% Create subset of asset returns
startAsset = 1; %To be removed
endAsset = startAsset + noAssets;
subSetOfAssetReturns = assetReturns(:,startAsset:endAsset);

% Calculate covar matrix
covarMat = cov(assetReturns(:,2:end));
covarMat = covarMat(1:noAssets,1:noAssets);

%% Get risk parity portfolio

[weightsRiskParity, functionValue] = getPortfolioRiskParity(subSetOfAssetReturns);
disp('RP done');
disp(strcat('Elapsed time: ',num2str(elapsedTime)));

%% Calculate TRCs for risk parity portfolio
TRCs = zeros(1,length(weightsRiskParity));

for i=1:length(weightsRiskParity)
    TRCi = calculateTotalRiskContribution(subSetOfAssetReturns,weightsRiskParity,percentile,i,risk);
    TRCs(1,i) = TRCi;
end

%% Write output data from part 2 to textfile
filename=strcat('output-20160413-',num2str(percentile),'-',risk,'.txt');
f=fopen(filename,'at');
formatspec = '\nRisk measure:\t\t%s\n';
fprintf(f,formatspec, risk);
formatspec = 'Sector:\t\t\t%s\t\n';
fprintf(f,formatspec, num2str(startSector));
formatspec = 'Assets:\t\t\t%s to %s\n';
fprintf(f,formatspec, num2str(startAsset), num2str(endAsset));
formatspec = 'Number of assets:\t%d \nPercentile:\t\t%d\nElapsed time:\t\t%f seconds\nNo of iterations:\t%d\n\nObjective value:\t%d\n\nCalculated weights risk parity:\n';
fprintf(f,formatspec,noAssets, percentile, elapsedTime,round(noIterations),functionValue);
fprintf(f,'%f;', weightsRiskParity);
fprintf(f,'\n\nCalculated TRCs:\n');
fprintf(f,'%f;',TRCs);
fprintf(f,'\n\n-----------------------------------------------------------------');
fclose(f);


