function [ sumTRCdev ] = optimizerTargetFunction(assetReturns, assetWeights, percentile, risk)
% Returns the target function value given the inputs during a run in the solver
%
% assetReturns: Txn matrix on the form [Date Stock1 ... StockN]
% assetWeights: nx1 vector of the portfolio weights for each asset
% percentile: VaR/CVaR percentile used as risk measure
% risk: string of wich risk measure to use

% calculate TRC for all stocks
TRCs = zeros(size(assetWeights,1));
for i=1:size(assetWeights,1)
    TRCs(i,1) = calculateTotalRiskContribution(assetReturns, assetWeights, percentile, i, risk);
end

% calculate target function value
sumTRCdev = 0;

for i=1:size(assetWeights,1)
    for j=1:size(assetWeights,1)
        sumTRCdev = sumTRCdev + (TRCs(i,1) - TRCs(j,1))^2;
    end
end

end