function [ pcaMat ] = principalComponentAnalysis( ReturnsMatrix, varExpMargin )
% Performs principal component analysis (PCA) on the returns matrix.
% Returns a matrix on the form [Date PC1 ... PCm], m <= n
% 
% Returnsmatrix: T*n+1 matrix, T observations by [Date stock1 ... stock n]
% varExpMargin: minimum requirement of explained variance by PCA

% format ReturnsMatrix
ReturnsMatrixMeans = mean(ReturnsMatrix);
ReturnsMatrix = principalComponentReturnMatrixFormatter(ReturnsMatrix, ReturnsMatrixMeans,true);

% get covar of returns matrix NxN
covarMat = cov(ReturnsMatrix(:,2:end));

% get vector of eigen values
[eigenMatrix, eigenVec] = eig(covarMat);
eigenMatrix = fliplr(eigenMatrix);

nrColsNeeded = getNumberOfPCColumns(eigenVec, varExpMargin);

% perform PCA matrix multiplication
pcaMat = [ReturnsMatrix(:,1) ReturnsMatrix(:,2:end) * eigenMatrix(:,1:nrColsNeeded)];

end

