function [ simulatedPCs ] = principalComponentSimulationFullSet( eigenMatrix, cholesky, mu, nrColsNeeded, lastDate, dayInterval, simulationSteps )
% Returns a matrix of simulated principal components FROM THE FULL SET WITH OUT REDUCTION TRICK i.e it simulates the entire tilde(X) 
% returns a matrix on the form 
% [Date PC1 ... PCm], m < n
% 
% eigenMatrix: matrix of eigenvectors used in the PCA
% cholesky: the lower cholesky matrix of the eigenMatrix
% mu: row vector with the drift of every stock
% nrColsNeeded: nr of columns needed to cover the margin of explained
% variance
% lastDate: last date of historical data
% dayInterval: dayinterval between two consecutive historical prices
% simulationSteps: nr of simulation steps into the future

simPCs = zeros(simulationSteps,nrColsNeeded+1);
for i=1:simulationSteps
    rndVector = norminv(rand(1,size(cholesky,2)),0,1);
    simX = mu(:,2:end) + rndVector*cholesky;
    simPCs(i,:) = [(lastDate + dayInterval*i) (simX*eigenMatrix)];
end

simulatedPCs = simPCs;

end