function [ simulatedPCs ] = principalComponentSimulationMinor( eigenMatrix, cholesky, mu, nrColsNeeded, lastDate, dayInterval, simulationSteps )
% Returns a matrix of simulated principal components on the form 
% [Date PC1 ... PCm], m < n
% this function is a sub procedure of the bigger function principalComponentSimulation
% 
% eigenMatrix: matrix of eigenvectors used in the PCA
% cholesky: the lower cholesky matrix of the eigenMatrix
% mu: row vector with the drift of every stock
% nrColsNeeded: nr of columns needed to cover the margin of explained
% variance
% lastDate: last date of historical data
% dayInterval: dayinterval between two consecutive historical prices
% simulationSteps: nr of simulation steps into the future

simPCs = zeros(simulationSteps,nrColsNeeded+1);
for i=1:simulationSteps
    rndVector = norminv(rand(1,nrColsNeeded),0,1);
    simPCs(i,:) = [(lastDate + dayInterval*i) (mu(:,2:end)*eigenMatrix + rndVector*cholesky)];
end

simulatedPCs = simPCs;

end

