# R script reads a return matrix from a csv file and the corresponding principal components
# runs quantile regression on the specified quantiles and saves output into a new csv file
# install.packages("quantreg")

# include quantile regression library
library(quantreg)
# create path to folder 
pathToDataFolder <- paste(getwd(),paste("Skole", "QuantileRegressions", sep="/"), sep="/")
pathToDataFolder
# quantiles to run regression on
quantiles <- c(0.01,0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.99)

# read data for the regression
returns <- read.csv(paste(pathToDataFolder,'returnMatrixSP80Sector55.csv',sep="/"),header=TRUE, sep=",")
pcs <- read.csv(paste(pathToDataFolder,'PCAColumnsSP80Sector55VarExp95.csv',sep="/"),header=FALSE, sep=",")

# convert to matrices
returnMatrix <- as.matrix(returns)
pcsMatrix <- as.matrix(pcs)

# select columns to be included in quantile regression
retCols <- cbind(2:length(returnMatrix[1,]))
pcCols <- cbind(2:length(pcsMatrix[1,]))

# perform quantile regression
regs <- list()
for(i in retCols) {
  print(i)
  regs[[i-1]] <- summary(rq(returnMatrix[,i] ~ pcsMatrix[,pcCols], tau=quantiles))
}

nrCoefs <- length(coef(regs[[1]][[1]])[,1])

# add first regression to data frame
x <- as.data.frame(t(coef(regs[[1]][[1]])[,1]))
names(x) = 1:nrCoefs
x['percentile'] = 0.01
x['index'] = 1

for(i in 1:length(regs)){
  for(j in 1:length(quantiles)) {
    if(i == 1 & j == 1) {
      next
    } else {
      row <- c(coef(regs[[i]][[j]])[,1], regs[[i]][[j]][6],i)
      names(row) <- c(1:nrCoefs, 'percentile', 'index')
      x <- rbind(x, row)
    }
  }
}
write.csv(x,file=paste(pathToDataFolder,'quantRegSP80Sector55varExp95.csv',sep="/"), row.names = FALSE)